@@ -25,7 +25,7 @@ JobTrackerSearchWidgetTest::~JobTrackerSearchWidgetTest()
 void JobTrackerSearchWidgetTest::shouldHaveDefaultValue()
 {
     JobTrackerSearchWidget w;
-    auto *mainLayout = w.findChild<QHBoxLayout *>(QStringLiteral("mainlayout"));
+    auto mainLayout = w.findChild<QHBoxLayout *>(QStringLiteral("mainlayout"));
     QVERIFY(mainLayout);
     int top = -1;
     int bottom = -1;
@@ -37,17 +37,17 @@ void JobTrackerSearchWidgetTest::shouldHaveDefaultValue()
     QCOMPARE(left, 0);
     QCOMPARE(right, 0);
 
-    auto *mSearchLineEdit = w.findChild<QLineEdit *>(QStringLiteral("searchline"));
+    auto mSearchLineEdit = w.findChild<QLineEdit *>(QStringLiteral("searchline"));
     QVERIFY(mSearchLineEdit);
     QVERIFY(mSearchLineEdit->isClearButtonEnabled());
     QVERIFY(mSearchLineEdit->text().isEmpty());
 
-    auto *mSelectColumn = w.findChild<QComboBox *>(QStringLiteral("selectcolumn"));
+    auto mSelectColumn = w.findChild<QComboBox *>(QStringLiteral("selectcolumn"));
     QVERIFY(mSelectColumn);
     QCOMPARE(mSelectColumn->count(), 8);
     QCOMPARE(mSelectColumn->currentIndex(), 0);
 
-    auto *mSelectOnlyError = w.findChild<QCheckBox *>(QStringLiteral("selectonlyerror"));
+    auto mSelectOnlyError = w.findChild<QCheckBox *>(QStringLiteral("selectonlyerror"));
     QVERIFY(mSelectOnlyError);
     QVERIFY(!mSelectOnlyError->text().isEmpty());
     QCOMPARE(mSelectOnlyError->checkState(), Qt::Unchecked);
@@ -57,7 +57,7 @@ void JobTrackerSearchWidgetTest::shouldEmitSignal()
 {
     JobTrackerSearchWidget w;
     QSignalSpy searchWidgetSignal(&w, &JobTrackerSearchWidget::searchTextChanged);
-    auto *mSearchLineEdit = w.findChild<QLineEdit *>(QStringLiteral("searchline"));
+    auto mSearchLineEdit = w.findChild<QLineEdit *>(QStringLiteral("searchline"));
     const QString foo = QStringLiteral("foo");
     mSearchLineEdit->setText(foo);
     QCOMPARE(searchWidgetSignal.count(), 1);
@@ -71,7 +71,7 @@ void JobTrackerSearchWidgetTest::shouldEmitColumnChanged()
 {
     JobTrackerSearchWidget w;
     QSignalSpy columnChangedSignal(&w, &JobTrackerSearchWidget::columnChanged);
-    auto *mSelectColumn = w.findChild<QComboBox *>(QStringLiteral("selectcolumn"));
+    auto mSelectColumn = w.findChild<QComboBox *>(QStringLiteral("selectcolumn"));
     mSelectColumn->setCurrentIndex(2);
     QCOMPARE(columnChangedSignal.count(), 1);
 }
@@ -80,7 +80,7 @@ void JobTrackerSearchWidgetTest::shouldEmitSelectOnlyErrorChanged()
 {
     JobTrackerSearchWidget w;
     QSignalSpy selectOnlyErrorChangedSignal(&w, &JobTrackerSearchWidget::selectOnlyErrorChanged);
-    auto *mSelectOnlyError = w.findChild<QCheckBox *>(QStringLiteral("selectonlyerror"));
+    auto mSelectOnlyError = w.findChild<QCheckBox *>(QStringLiteral("selectonlyerror"));
     mSelectOnlyError->setChecked(true);
     QCOMPARE(selectOnlyErrorChangedSignal.count(), 1);
 }
