@@ -12,17 +12,16 @@
 
 #include <QColor>
 #include <QFont>
-#include <QLocale>
 #include <QModelIndex>
 #include <QPair>
 #include <QStringList>
 
 #include <cassert>
 
-class JobTrackerModel::Private
+class JobTrackerModelPrivate
 {
 public:
-    Private(const char *name, JobTrackerModel *_q)
+    JobTrackerModelPrivate(const char *name, JobTrackerModel *_q)
         : q(_q)
         , tracker(name)
     {
@@ -53,17 +52,14 @@ public:
 
 JobTrackerModel::JobTrackerModel(const char *name, QObject *parent)
     : QAbstractItemModel(parent)
-    , d(new Private(name, this))
+    , d(new JobTrackerModelPrivate(name, this))
 {
     connect(&d->tracker, &JobTracker::aboutToAdd, this, &JobTrackerModel::jobAboutToBeAdded);
     connect(&d->tracker, &JobTracker::added, this, &JobTrackerModel::jobAdded);
     connect(&d->tracker, &JobTracker::updated, this, &JobTrackerModel::jobsUpdated);
 }
 
-JobTrackerModel::~JobTrackerModel()
-{
-    delete d;
-}
+JobTrackerModel::~JobTrackerModel() = default;
 
 JobTracker &JobTrackerModel::jobTracker()
 {
